@@ -25,17 +25,23 @@ int main(int argc, char *argv[])
     char *serv_cert = NULL;
     char *serv_key = NULL;
     char *proxy_cert = NULL;
+    canl_principal princ = NULL;
+    int get_peer_princ = 0;
+    char *name = NULL;
+    int ocsp_on = 0;
 
     timeout.tv_sec = DEF_TIMEOUT;
     timeout.tv_usec = 0;
 
-    while ((opt = getopt(argc, argv, "hp:s:c:k:t:")) != -1) {
+    while ((opt = getopt(argc, argv, "nhop:s:c:k:t:")) != -1) {
         switch (opt) {
             case 'h':
                 fprintf(stderr, "Usage: %s [-p port] [-c certificate]"
                         " [-k private key] [-d ca_dir] [-h] "
                         " [-s server] [-x proxy certificate] "
-                        " [-t timeout] \n", argv[0]);
+                        "[-t timeout] [-n {print peer's princ name}] "
+                        "[-o {turn OCSP on}] "
+                        " \n", argv[0]);
                 exit(0);
             case 'p':
                 port = atoi(optarg);
@@ -58,11 +64,19 @@ int main(int argc, char *argv[])
             case 't':
                 timeout.tv_sec = atoi(optarg);
                 break;
+            case 'n':
+                get_peer_princ = 1;
+                break;
+            case 'o':
+                ocsp_on = 1;
+                break;
             default: /* '?' */
                 fprintf(stderr, "Usage: %s [-p port] [-c certificate]"
                         " [-k private key] [-d ca_dir] [-h]"
                         " [-s server] [-x proxy certificate]"
-                        " [-t timeout] \n", argv[0]);
+                        "[-t timeout] [-n {print peer's princ name}] "
+                        "[-o {turn OCSP on}] "
+                        " \n", argv[0]);
                 exit(-1);
         }
     }
@@ -93,15 +107,31 @@ int main(int argc, char *argv[])
             goto end;
         }
     }
+    if (ocsp_on)
+        canl_ctx_set_ssl_flags(my_ctx, CANL_SSL_OCSP_VERIFY_ALL);
 
-    err = canl_io_connect(my_ctx, my_io_h, p_server, NULL, port, NULL, 0,
-            NULL, &timeout);
-    if (err) {
-        printf("[CLIENT] connection to %s cannot be established:\n[CANL] %s\n",
-	       p_server, canl_get_error_message(my_ctx));
-        goto end;
+     if (get_peer_princ) {
+        err = canl_io_connect(my_ctx, my_io_h, p_server, NULL, port, NULL, 0,
+            &princ, &timeout);
+        if (err) {
+            printf("[CLIENT] connection cannot be established:\n[CANL] %s\n",
+                    canl_get_error_message(my_ctx));
+            goto end;
+        }
+
+        err = canl_princ_name(my_ctx, princ, &name);
+        printf("[CLIENT] connection established with %s\n", name);
+        free(name);
+        canl_princ_free(my_ctx, princ);
     }
-    else {
+    else{
+        err = canl_io_connect(my_ctx, my_io_h, p_server, NULL, port, NULL, 0,
+            NULL, &timeout);
+        if (err) {
+            printf("[CLIENT] connection cannot be established:\n[CANL] %s\n",
+                    canl_get_error_message(my_ctx));
+            goto end;
+        }
         printf("[CLIENT] connection established\n");
     }
 
