@@ -20,7 +20,7 @@ static canl_error map_proxy_error(int reason);
 
 static int setup_SSL_proxy_handler(glb_ctx *cc, SSL_CTX *ssl, char *cadir,
         int leave_pvd);
-extern proxy_verify_desc *pvd_setup_initializers(char *cadir);
+extern proxy_verify_desc *pvd_setup_initializers(char *cadir, int flags);
 extern void pvd_destroy_initializers(void *data);
 
 #ifdef DEBUG
@@ -87,8 +87,7 @@ ssl_initialize(glb_ctx *cc)
     if (ca_cert_dirn)
         free(ca_cert_dirn);
 
-    //err = SSL_CTX_set_cipher_list(ssl_ctx, "ALL:!LOW:!EXP:!MD5:!MD2");
-    err = SSL_CTX_set_cipher_list(ssl_ctx, "ALL");
+    err = SSL_CTX_set_cipher_list(ssl_ctx, "ALL:!LOW:!EXP:!MD5:!MD2");
     if (!err) {
         err = set_error(cc, ERR_get_error(), SSL_ERROR,
                 "Error setting cipher list");
@@ -393,7 +392,7 @@ static int setup_SSL_proxy_handler(glb_ctx *cc, SSL_CTX *ssl, char *cadir,
 {
     proxy_verify_desc *new_pvd = NULL;
     mech_glb_ctx *m_ctx = (mech_glb_ctx *)cc->mech_ctx;
-    new_pvd =  pvd_setup_initializers(cadir);
+    new_pvd =  pvd_setup_initializers(cadir, m_ctx->flags);
     if (new_pvd){
         SSL_CTX_set_ex_data(ssl, PVD_SSL_EX_DATA_IDX, new_pvd);
         if (!leave_pvd)
@@ -1151,7 +1150,6 @@ canl_ctx_set_ssl_cred(canl_ctx cc, char *cert, char *key, char *proxy,
     return err;
 }
 
-
 canl_err_code 
 canl_ctx_set_ssl_flags(canl_ctx cc, unsigned int flags)
 {
